Algorithm descriptions
=================


Forward operator
---------------------------------

.. automodule:: sicor.AC.RtFo_3_phases
    :members:
    :undoc-members:
    :show-inheritance:

LUT
-------------------------------

.. automodule:: sicor.Tools.EnMAP.LUT
    :members:
    :undoc-members:
    :show-inheritance:

Conversion
--------------------------------------

.. automodule:: sicor.Tools.EnMAP.conversion
    :members:
    :undoc-members:
    :show-inheritance:

Metadata
------------------------------------

.. automodule:: sicor.Tools.EnMAP.metadata
    :members:
    :undoc-members:
    :show-inheritance:

Multiprocessing
-------------------------------------------

.. automodule:: sicor.Tools.EnMAP.multiprocessing
    :members:
    :undoc-members:
    :show-inheritance:

Optimal Estimation (OE)
-----------------------------------------------

.. automodule:: sicor.Tools.EnMAP.optimal_estimation
    :members:
    :undoc-members:
    :show-inheritance:
